import postcss, { Root, Node, AcceptedPlugin } from 'postcss';
import { Options } from 'sass';
import { Config } from 'tailwindcss';
import { AtImportOptions } from 'postcss-import';
import { GeneratorOptions } from '@babel/generator';

interface IProcessOptions {
    tailwindcssResolved?: boolean;
    tailwindcssConfig?: string | Config | {
        config: string | Config;
    } | undefined;
    sassOptions?: Options<'sync'>;
    atImportOptions?: AtImportOptions;
    generatorOptions?: GeneratorOptions;
    outSideLayerCss?: 'base' | 'components' | 'utilities' | ((root: Root, ctx: IContext) => void);
}
type TailwindcssPluginOptions = {
    entries: string[];
    cacheDir?: string;
} & IProcessOptions;

type NodeMapKeys = 'base' | 'components' | 'utilities';
declare function createContext(opts?: IProcessOptions): {
    options: Required<IProcessOptions>;
    layersMap: Map<NodeMapKeys, Node[]>;
    append: (key: NodeMapKeys, nodes: Node | Node[]) => void;
    getNodes: (key: NodeMapKeys) => Node[];
    getPluginsSync(): AcceptedPlugin[];
    getPlugins(): Promise<AcceptedPlugin[]>;
    process(entry: string): Promise<postcss.Result<postcss.Root>>;
    processSync(entry: string): postcss.Result<postcss.Document | postcss.Root>;
    generate: () => string;
};
type IContext = ReturnType<typeof createContext>;

export { type IContext as I, type NodeMapKeys as N, type TailwindcssPluginOptions as T, createContext as c };
